/******************************************************************************
 File:    hilib.h
 Purpose: Hostess i/S2 header file for system C language interface library.
 Company: Comtrol Corporation
 Author:  Craig Harrison
 Ident:   $Id$
*******************************************************************************
 Copyright 1994 Comtrol Corporation. All rights reserved.
 Subject to developers license agreement.
******************************************************************************/

#ifndef DPRAM_H
#include "dpram.h"
#define DPRAM_H 1
#endif

/* ----- Control register defines ------------------------------------------ */
#define EN_RAM    0x00        /* Enable DPRAM */
#define CR1       0x01        /* Select Control Reg 1 */
#define CR2       0x02        /* Select Control Reg 2 */
#define DIS_RAM   0x04        /* Disable DPRAM */
#define CR3       0x08        /* Select Control Reg 3 */
#define CR4       0x10        /* Select Control Reg 4 */
#define AT_MODE   0x80        /* set AT mode in CR1 */

/* ----- CR2 values for below 1 Meg addresses ------------------------------ */
#define ADD80000 0x20
#define ADD90000 0x24
#define ADDA0000 0x28
#define ADDB0000 0x2c
#define ADDC0000 0x30
#define ADDD0000 0x34
#define ADDE0000 0x38
#define ADDF0000 0x3c
#define CR2_VAL  ADDD0000

/* ----- Firmware utility defines ------------------------------------------ */
#define COPY      0x02        /* firmware utility copy command */
#define EXEC      0x01        /* firmware utility execute ctrlpgm command */
#define DONE      0x01        /* firmware utility DONE status flag */

/* ----- Other defines ---------------------------------------------------- */
#define REPLY_TIMEOUT 2          /* reply timeout in seconds */
#define DP_XFER_MAX 32           /* max num bytes to xfer to/from dual port
                                    mem at one time to avoid hogging CTL bus */

/* ----- Interrupt information structure ----------------------------------- */
typedef struct
{
   BYTE_T Mask;                        /* mask value for 8259 mask register */
   WORD_T IntNum;                      /* interrupt num (this not IRQ num) */
   WORD_T MaskIO;                      /* I/O address of 8259 mask register */
   BYTE_T Cr4;                         /* controller Control Register 4 */
} IRQ_T;


/* ----- Function Prototypes ----------------------------------------------- */
int hiChangeModem(int,int,int);
int hiClose(int);
void hiClrSfg(int,UWORD_T);
UWORD_T hiDecrementSfg(int);
void hiDelay(long);
int hiDeqSysMsg(char *);
void hiEndOfInterrupt(void);
int hiEnqCtlMsg(BYTE_T *,BYTE_T *);
void hiGetDpSem(void);
int hiGetModem(int);
int hiGetRxBufCnt(int);
int hiGetRxByteCnt(int);
UWORD_T hiGetSfg(int,UWORD_T);
int hiGetSysMsgStatus(void);
int hiGetTxBufCnt(int);
int hiGetTxByteCnt(int);
UWORD_T hiIncrementSfg(int);
void hiInitDpm(void);
void hiInitSfg(int,UWORD_T);
void hiInstallIrq(int,void (interrupt far *)());
void hiMemCpy(char far *dest,char far *src,unsigned n);
int hiOpenAsync(int,int,int,int,int,int);
int hiOpenBisync(int,int,int,long);
int hiOpenHdlc(int,int,int,long);
int hiReadAsync(int,BYTE_T *,int);
int hiReadSync(int,BYTE_T *);
void hiRestoreIrq(void);
void hiSetSfg(int,UWORD_T);
UWORD_T hiTestSetSfg(int,UWORD_T);
int hiWriteAsync(int,BYTE_T *,int);
int hiWriteSync(int,BYTE_T *,int);
WORD_T GetTxqOut(LINE_T far *);
WORD_T GetRxqIn(LINE_T far *);


/* ----- Macros ------------------------------------------------------------ */
#if defined(BORLANDC)
#define OUTB(PORT,VALUE) outportb(PORT,VALUE)
#define INB(PORT) inportb(PORT)
#define hiEN_INT() enable()
#define hiDIS_INT() disable()
#endif

#if defined(MSC)
#define OUTB(PORT,VALUE) outp(PORT,VALUE)
#define INB(PORT) inp(PORT)
#define hiEN_INT() _enable()
#define hiDIS_INT() _disable()
#endif

/*****************************************************************************
Macro:      hiREL_DPSEM
Purpose:    Release dual port semaphore.
Comments:   This macro is used to release the dual port semaphore
            after hiGetDpSem() is called.
*/
#define hiREL_DPSEM() *pDpSemSysAccess = 0


